@@ -22,7 +22,7 @@ hook_plot_rst = function(x, options) {
 #' @export
 render_rst = function(strict = FALSE) {
   knit_hooks$restore()
-  opts_chunk$set(dev = 'png', highlight = FALSE)
+  set_html_dev()
   hook.s = function(x, options) {
     str_c('\n\n::\n\n', indent_block(x), '\n')
   }
@@ -36,9 +36,13 @@ render_rst = function(strict = FALSE) {
   hook.i = function(x) {
     .inline.hook(format_sci(x, 'rst'))
   }
-  knit_hooks$set(source = if (strict) hook.s else hook.t,
-                 warning = hook.s, error = hook.s, message = hook.s,
-                 output = hook.o, inline = hook.i, plot = hook_plot_rst)
+  knit_hooks$set(
+    source = function(x, options) {
+      x = paste(c(hilight_source(x, 'rst', options), ''), collapse = '\n')
+      (if (strict) hook.s else hook.t)(x, options)
+    },
+    warning = hook.s, error = hook.s, message = hook.s,
+    output = hook.o, inline = hook.i, plot = hook_plot_rst)
 }
 
 # Insert a reStructuredText directive for sphinx
