@@ -5,9 +5,9 @@ kable(mtcars, 'html', table.attr='id="mtcars_table"')
 
 
 ## ------------------------------------------------------------------------
-options(markdown.HTML.header = paste(unlist(
+options(markdown.HTML.header = unlist(
   sapply(system.file('misc', c('vignette.css', 'datatables.txt'), package = 'knitr'), readLines)
-  ), collapse = '\n')
+  )
 )
 
 
